@@ -27,15 +27,14 @@ from webob.exc import HTTPAccepted, HTTPBadRequest, \
     HTTPCreated, HTTPForbidden, HTTPInternalServerError, \
     HTTPMethodNotAllowed, HTTPNoContent, HTTPNotFound, \
     HTTPPreconditionFailed, HTTPConflict
-import simplejson
 
 import swift.common.db
 from swift.common.db import AccountBroker
 from swift.common.utils import get_logger, get_param, hash_path, public, \
     normalize_timestamp, split_path, storage_directory, TRUE_VALUES, \
-    validate_device_partition
+    validate_device_partition, json
 from swift.common.constraints import ACCOUNT_LISTING_LIMIT, \
-    check_mount, check_float, check_utf8
+    check_mount, check_float, check_utf8, FORMAT2CONTENT_TYPE
 from swift.common.db_replicator import ReplicatorRpc
 from swift.common.http import HTTPInsufficientStorage
 
@@ -252,11 +251,8 @@ class AccountController(object):
             return HTTPBadRequest(body='parameters not utf8',
                                   content_type='text/plain', request=req)
         if query_format:
-            qfmt_lower = query_format.lower()
-            if qfmt_lower not in ['xml', 'json', 'plain']:
-                return HTTPBadRequest(body='format not supported',
-                                      content_type='text/plain', request=req)
-            req.accept = 'application/%s' % qfmt_lower
+            req.accept = FORMAT2CONTENT_TYPE.get(query_format.lower(),
+                                                 FORMAT2CONTENT_TYPE['plain'])
         try:
             out_content_type = req.accept.best_match(
                                     ['text/plain', 'application/json',
@@ -269,17 +265,14 @@ class AccountController(object):
         account_list = broker.list_containers_iter(limit, marker, end_marker,
                                                    prefix, delimiter)
         if out_content_type == 'application/json':
-            json_pattern = ['"name":%s', '"count":%s', '"bytes":%s']
-            json_pattern = '{' + ','.join(json_pattern) + '}'
-            json_out = []
+            data = []
             for (name, object_count, bytes_used, is_subdir) in account_list:
-                name = simplejson.dumps(name)
                 if is_subdir:
-                    json_out.append('{"subdir":%s}' % name)
+                    data.append({'subdir': name})
                 else:
-                    json_out.append(json_pattern %
-                        (name, object_count, bytes_used))
-            account_list = '[' + ','.join(json_out) + ']'
+                    data.append({'name': name, 'count': object_count,
+                                'bytes': bytes_used})
+            account_list = json.dumps(data)
         elif out_content_type.endswith('/xml'):
             output_list = ['<?xml version="1.0" encoding="UTF-8"?>',
                            '<account name="%s">' % account]
@@ -324,7 +317,7 @@ class AccountController(object):
             self.logger.increment('REPLICATE.errors')
             return HTTPInsufficientStorage(drive=drive, request=req)
         try:
-            args = simplejson.load(req.environ['wsgi.input'])
+            args = json.load(req.environ['wsgi.input'])
         except ValueError, err:
             self.logger.increment('REPLICATE.errors')
             return HTTPBadRequest(body=str(err), content_type='text/plain')
