@@ -170,8 +170,7 @@ def fallocate(fd, size):
         # 1 means "FALLOC_FL_KEEP_SIZE", which means it pre-allocates invisibly
         ret = _sys_fallocate(fd, 1, 0, ctypes.c_uint64(size))
         err = ctypes.get_errno()
-        if ret and err not in (0, errno.ENOSYS, errno.EOPNOTSUPP,
-                               errno.EINVAL):
+        if ret and err not in (0, errno.ENOSYS, errno.EOPNOTSUPP):
             raise OSError(err, 'Unable to fallocate(%s)' % size)
 
 
@@ -605,8 +604,7 @@ def get_logger(conf, name=None, log_to_console=False, log_route=None,
         try:
             handler = SysLogHandler(address=log_address, facility=facility)
         except socket.error, e:
-            # Either /dev/log isn't a UNIX socket or it does not exist at all
-            if e.errno not in [errno.ENOTSOCK,  errno.ENOENT]:
+            if e.errno != errno.ENOTSOCK:  # Socket operation on non-socket
                 raise e
             handler = SysLogHandler(facility=facility)
     handler.setFormatter(formatter)
@@ -685,12 +683,7 @@ def capture_stdio(logger, **kwargs):
     with open(os.devnull, 'r+b') as nullfile:
         # close stdio (excludes fds open for logging)
         for f in stdio_files:
-            # some platforms throw an error when attempting an stdin flush
-            try:
-                f.flush()
-            except IOError:
-                pass
-
+            f.flush()
             try:
                 os.dup2(nullfile.fileno(), f.fileno())
             except OSError:
