@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
 import time
 from random import random
 
@@ -22,7 +23,7 @@ import swift.common.db
 from swift.container import server as container_server
 from swift.common.db import ContainerBroker
 from swift.common.utils import get_logger, audit_location_generator, \
-    TRUE_VALUES
+    TRUE_VALUES, dump_recon_cache
 from swift.common.daemon import Daemon
 
 
@@ -36,47 +37,15 @@ class ContainerAuditor(Daemon):
         self.mount_check = conf.get('mount_check', 'true').lower() in \
                               ('true', 't', '1', 'on', 'yes', 'y')
         self.interval = int(conf.get('interval', 1800))
-        swift_dir = conf.get('swift_dir', '/etc/swift')
         self.container_passes = 0
         self.container_failures = 0
         swift.common.db.DB_PREALLOCATION = \
-            conf.get('db_preallocation', 't').lower() in TRUE_VALUES
+            conf.get('db_preallocation', 'f').lower() in TRUE_VALUES
+        self.recon_cache_path = conf.get('recon_cache_path',
+                                         '/var/cache/swift')
+        self.rcache = os.path.join(self.recon_cache_path, "container.recon")
 
-    def run_forever(self, *args, **kwargs):
-        """Run the container audit until stopped."""
-        reported = time.time()
-        time.sleep(random() * self.interval)
-        while True:
-            self.logger.info(_('Begin container audit pass.'))
-            begin = time.time()
-            try:
-                all_locs = audit_location_generator(self.devices,
-                    container_server.DATADIR, mount_check=self.mount_check,
-                    logger=self.logger)
-                for path, device, partition in all_locs:
-                    self.container_audit(path)
-                    if time.time() - reported >= 3600:  # once an hour
-                        self.logger.info(
-                            _('Since %(time)s: Container audits: %(pass)s '
-                              'passed audit, %(fail)s failed audit'),
-                            {'time': time.ctime(reported),
-                             'pass': self.container_passes,
-                             'fail': self.container_failures})
-                        reported = time.time()
-                        self.container_passes = 0
-                        self.container_failures = 0
-            except (Exception, Timeout):
-                self.logger.exception(_('ERROR auditing'))
-            elapsed = time.time() - begin
-            if elapsed < self.interval:
-                time.sleep(self.interval - elapsed)
-            self.logger.info(
-                _('Container audit pass completed: %.02fs'), elapsed)
-
-    def run_once(self, *args, **kwargs):
-        """Run the container audit once."""
-        self.logger.info(_('Begin container audit "once" mode'))
-        begin = reported = time.time()
+    def _one_audit_pass(self, reported):
         all_locs = audit_location_generator(self.devices,
                                             container_server.DATADIR,
                                             mount_check=self.mount_check,
@@ -90,12 +59,47 @@ class ContainerAuditor(Daemon):
                     {'time': time.ctime(reported),
                      'pass': self.container_passes,
                      'fail': self.container_failures})
+                dump_recon_cache({'container_audits_since': reported,
+                                  'container_audits_passed':
+                                    self.container_passes,
+                                  'container_audits_failed':
+                                    self.container_failures},
+                                 self.rcache, self.logger)
                 reported = time.time()
                 self.container_passes = 0
                 self.container_failures = 0
+        return reported
+
+    def run_forever(self, *args, **kwargs):
+        """Run the container audit until stopped."""
+        reported = time.time()
+        time.sleep(random() * self.interval)
+        while True:
+            self.logger.info(_('Begin container audit pass.'))
+            begin = time.time()
+            try:
+                reported = self._one_audit_pass(reported)
+            except (Exception, Timeout):
+                self.logger.increment('errors')
+                self.logger.exception(_('ERROR auditing'))
+            elapsed = time.time() - begin
+            if elapsed < self.interval:
+                time.sleep(self.interval - elapsed)
+            self.logger.info(
+                _('Container audit pass completed: %.02fs'), elapsed)
+            dump_recon_cache({'container_auditor_pass_completed': elapsed},
+                             self.rcache, self.logger)
+
+    def run_once(self, *args, **kwargs):
+        """Run the container audit once."""
+        self.logger.info(_('Begin container audit "once" mode'))
+        begin = reported = time.time()
+        self._one_audit_pass(reported)
         elapsed = time.time() - begin
         self.logger.info(
             _('Container audit "once" mode completed: %.02fs'), elapsed)
+        dump_recon_cache({'container_auditor_pass_completed': elapsed},
+                          self.recon_container)
 
     def container_audit(self, path):
         """
@@ -103,15 +107,19 @@ class ContainerAuditor(Daemon):
 
         :param path: the path to a container db
         """
+        start_time = time.time()
         try:
             if not path.endswith('.db'):
                 return
             broker = ContainerBroker(path)
             if not broker.is_deleted():
                 info = broker.get_info()
+                self.logger.increment('passes')
                 self.container_passes += 1
                 self.logger.debug(_('Audit passed for %s'), broker.db_file)
         except (Exception, Timeout):
+            self.logger.increment('failures')
             self.container_failures += 1
             self.logger.exception(_('ERROR Could not get container info %s'),
                 (broker.db_file))
+        self.logger.timing_since('timing', start_time)
