@@ -29,8 +29,9 @@ from swift.common.bufferedhttp import http_connect
 from swift.common.db import ContainerBroker
 from swift.common.exceptions import ConnectionTimeout
 from swift.common.ring import Ring
-from swift.common.utils import get_logger, whataremyips, TRUE_VALUES
+from swift.common.utils import get_logger, TRUE_VALUES, dump_recon_cache
 from swift.common.daemon import Daemon
+from swift.common.http import is_success, HTTP_INTERNAL_SERVER_ERROR
 
 
 class ContainerUpdater(Daemon):
@@ -57,7 +58,10 @@ class ContainerUpdater(Daemon):
             float(conf.get('account_suppression_time', 60))
         self.new_account_suppressions = None
         swift.common.db.DB_PREALLOCATION = \
-            conf.get('db_preallocation', 't').lower() in TRUE_VALUES
+            conf.get('db_preallocation', 'f').lower() in TRUE_VALUES
+        self.recon_cache_path = conf.get('recon_cache_path',
+                                         '/var/cache/swift')
+        self.rcache = os.path.join(self.recon_cache_path, "container.recon")
 
     def get_account_ring(self):
         """Get the account ring.  Load it if it hasn't been yet."""
@@ -153,6 +157,8 @@ class ContainerUpdater(Daemon):
             elapsed = time.time() - begin
             self.logger.info(_('Container update sweep completed: %.02fs'),
                              elapsed)
+            dump_recon_cache({'container_updater_sweep': elapsed},
+                             self.rcache, self.logger)
             if elapsed < self.interval:
                 time.sleep(self.interval - elapsed)
 
@@ -174,6 +180,8 @@ class ContainerUpdater(Daemon):
             '%(no_change)s with no changes'),
             {'elapsed': elapsed, 'success': self.successes,
              'fail': self.failures, 'no_change': self.no_changes})
+        dump_recon_cache({'container_updater_sweep': elapsed},
+                         self.rcache, self.logger)
 
     def container_sweep(self, path):
         """
@@ -193,6 +201,7 @@ class ContainerUpdater(Daemon):
 
         :param dbfile: container DB to process
         """
+        start_time = time.time()
         broker = ContainerBroker(dbfile, logger=self.logger)
         info = broker.get_info()
         # Don't send updates if the container was auto-created since it
@@ -214,11 +223,12 @@ class ContainerUpdater(Daemon):
             successes = 0
             failures = 0
             for event in events:
-                if 200 <= event.wait() < 300:
+                if is_success(event.wait()):
                     successes += 1
                 else:
                     failures += 1
             if successes > failures:
+                self.logger.increment('successes')
                 self.successes += 1
                 self.logger.debug(
                     _('Update report sent for %(container)s %(dbfile)s'),
@@ -227,6 +237,7 @@ class ContainerUpdater(Daemon):
                                 info['delete_timestamp'], info['object_count'],
                                 info['bytes_used'])
             else:
+                self.logger.increment('failures')
                 self.failures += 1
                 self.logger.debug(
                     _('Update report failed for %(container)s %(dbfile)s'),
@@ -236,7 +247,10 @@ class ContainerUpdater(Daemon):
                 if self.new_account_suppressions:
                     print >>self.new_account_suppressions, \
                         info['account'], until
+            # Only track timing data for attempted updates:
+            self.logger.timing_since('timing', start_time)
         else:
+            self.logger.increment('no_changes')
             self.no_changes += 1
 
     def container_report(self, node, part, container, put_timestamp,
@@ -265,7 +279,7 @@ class ContainerUpdater(Daemon):
             except (Exception, Timeout):
                 self.logger.exception(_('ERROR account update failed with '
                     '%(ip)s:%(port)s/%(device)s (will retry later): '), node)
-                return 500
+                return HTTP_INTERNAL_SERVER_ERROR
         with Timeout(self.node_timeout):
             try:
                 resp = conn.getresponse()
@@ -275,4 +289,4 @@ class ContainerUpdater(Daemon):
                 if self.logger.getEffectiveLevel() <= logging.DEBUG:
                     self.logger.exception(
                         _('Exception with %(ip)s:%(port)s/%(device)s'), node)
-                return 500
+                return HTTP_INTERNAL_SERVER_ERROR
