@@ -14,7 +14,7 @@
 # limitations under the License.
 
 import os
-from os.path import basename, dirname, isdir, isfile, join
+from os.path import basename, dirname, isdir, join
 import random
 import shutil
 import time
@@ -33,11 +33,10 @@ from eventlet.support.greenlets import GreenletExit
 from swift.common.ring import Ring
 from swift.common.utils import whataremyips, unlink_older_than, lock_path, \
         compute_eta, get_logger, write_pickle, renamer, dump_recon_cache, \
-        rsync_ip, mkdirs
+        rsync_ip
 from swift.common.bufferedhttp import http_connect
 from swift.common.daemon import Daemon
 from swift.common.http import HTTP_OK, HTTP_INSUFFICIENT_STORAGE
-from swift.common.exceptions import PathNotDir
 
 hubs.use_hub('poll')
 
@@ -76,17 +75,9 @@ def hash_suffix(path, reclaim_age):
     Performs reclamation and returns an md5 of all (remaining) files.
 
     :param reclaim_age: age in seconds at which to remove tombstones
-    :raises PathNotDir: if given path is not a valid directory
-    :raises OSError: for non-ENOTDIR errors
     """
     md5 = hashlib.md5()
-    try:
-        path_contents = sorted(os.listdir(path))
-    except OSError, err:
-        if err.errno == errno.ENOTDIR:
-            raise PathNotDir()
-        raise
-    for hsh in path_contents:
+    for hsh in sorted(os.listdir(path)):
         hsh_path = join(path, hsh)
         try:
             files = os.listdir(hsh_path)
@@ -186,20 +177,21 @@ def get_hashes(partition_dir, recalculate=[], do_listdir=False,
         do_listdir = True
     if do_listdir:
         for suff in os.listdir(partition_dir):
-            if len(suff) == 3:
+            if len(suff) == 3 and isdir(join(partition_dir, suff)):
                 hashes.setdefault(suff, None)
         modified = True
     hashes.update((hash_, None) for hash_ in recalculate)
     for suffix, hash_ in hashes.items():
         if not hash_:
             suffix_dir = join(partition_dir, suffix)
-            try:
-                hashes[suffix] = hash_suffix(suffix_dir, reclaim_age)
-                hashed += 1
-            except PathNotDir:
+            if isdir(suffix_dir):
+                try:
+                    hashes[suffix] = hash_suffix(suffix_dir, reclaim_age)
+                    hashed += 1
+                except OSError:
+                    logging.exception(_('Error hashing suffix'))
+            else:
                 del hashes[suffix]
-            except OSError:
-                logging.exception(_('Error hashing suffix'))
             modified = True
     if modified:
         with lock_path(partition_dir):
@@ -547,28 +539,19 @@ class ObjectReplicator(Daemon):
                 continue
             unlink_older_than(tmp_path, time.time() - self.reclaim_age)
             if not os.path.exists(obj_path):
-                mkdirs(obj_path)
                 continue
             for partition in os.listdir(obj_path):
                 try:
-                    job_path = join(obj_path, partition)
-                    if isfile(job_path):
-                        # Clean up any (probably zero-byte) files where a
-                        # partition should be.
-                        self.logger.warning('Removing partition directory '
-                                            'which was a file: %s', job_path)
-                        os.remove(job_path)
-                        continue
                     part_nodes = \
                         self.object_ring.get_part_nodes(int(partition))
                     nodes = [node for node in part_nodes
                              if node['id'] != local_dev['id']]
-                    jobs.append(dict(path=job_path,
+                    jobs.append(dict(path=join(obj_path, partition),
                         device=local_dev['device'],
                         nodes=nodes,
                         delete=len(nodes) > len(part_nodes) - 1,
                         partition=partition))
-                except ValueError, OSError:
+                except ValueError:
                     continue
         random.shuffle(jobs)
         # Partititons that need to be deleted take priority
