@@ -276,15 +276,13 @@ class ObjectController(Controller):
             for obj in sublisting:
                 yield obj
 
-    def GETorHEAD(self, req, stats_type):
+    def GETorHEAD(self, req):
         """Handle HTTP GET or HEAD requests."""
-        start_time = time.time()
         _junk, _junk, req.acl, _junk, _junk, object_versions = \
             self.container_info(self.account_name, self.container_name)
         if 'swift.authorize' in req.environ:
             aresp = req.environ['swift.authorize'](req)
             if aresp:
-                self.app.logger.increment('auth_short_circuits')
                 return aresp
         partition, nodes = self.app.object_ring.get_nodes(
             self.account_name, self.container_name, self.object_name)
@@ -305,8 +303,6 @@ class ObjectController(Controller):
                                                         self.app.object_ring),
                                         req.path_info, len(nodes))
             if 'x-object-manifest' not in resp2.headers:
-                self.app.logger.timing_since(
-                    '%s.timing' % (stats_type,), start_time)
                 return resp
             resp = resp2
             req.range = str(req_range)
@@ -320,14 +316,10 @@ class ObjectController(Controller):
                 listing = list(self._listing_iter(lcontainer, lprefix,
                                 req.environ))
             except ListingIterNotFound:
-                self.app.logger.timing_since(
-                    '%s.timing' % (stats_type,), start_time)
                 return HTTPNotFound(request=req)
             except ListingIterNotAuthorized, err:
-                self.app.logger.increment('auth_short_circuits')
                 return err.aresp
             except ListingIterError:
-                self.app.logger.increment('errors')
                 return HTTPServerError(request=req)
 
             if len(listing) > CONTAINER_LISTING_LIMIT:
@@ -346,8 +338,6 @@ class ObjectController(Controller):
                         return iter([])
 
                     head_response.status_int = resp.status_int
-                    self.app.logger.timing_since(
-                        '%s.timing' % (stats_type,), start_time)
                     return head_response
                 else:
                     resp.app_iter = SegmentedIterable(self, lcontainer,
@@ -377,31 +367,28 @@ class ObjectController(Controller):
                 resp.etag = etag
             resp.headers['accept-ranges'] = 'bytes'
 
-        self.app.logger.timing_since('%s.timing' % (stats_type,), start_time)
         return resp
 
     @public
     @delay_denial
     def GET(self, req):
         """Handler for HTTP GET requests."""
-        return self.GETorHEAD(req, stats_type='GET')
+        return self.GETorHEAD(req)
 
     @public
     @delay_denial
     def HEAD(self, req):
         """Handler for HTTP HEAD requests."""
-        return self.GETorHEAD(req, stats_type='HEAD')
+        return self.GETorHEAD(req)
 
     @public
     @delay_denial
     def POST(self, req):
         """HTTP POST request handler."""
-        start_time = time.time()
         if 'x-delete-after' in req.headers:
             try:
                 x_delete_after = int(req.headers['x-delete-after'])
             except ValueError:
-                self.app.logger.increment('errors')
                 return HTTPBadRequest(request=req,
                                       content_type='text/plain',
                                       body='Non-integer X-Delete-After')
@@ -415,7 +402,7 @@ class ObjectController(Controller):
                 self.object_name))
             req.headers['X-Fresh-Metadata'] = 'true'
             req.environ['swift_versioned_copy'] = True
-            resp = self.PUT(req, start_time=start_time, stats_type='POST')
+            resp = self.PUT(req)
             # Older editions returned 202 Accepted on object POSTs, so we'll
             # convert any 201 Created responses to that for compatibility with
             # picky clients.
@@ -425,7 +412,6 @@ class ObjectController(Controller):
         else:
             error_response = check_metadata(req, 'object')
             if error_response:
-                self.app.logger.increment('errors')
                 return error_response
             container_partition, containers, _junk, req.acl, _junk, _junk = \
                 self.container_info(self.account_name, self.container_name,
@@ -433,20 +419,16 @@ class ObjectController(Controller):
             if 'swift.authorize' in req.environ:
                 aresp = req.environ['swift.authorize'](req)
                 if aresp:
-                    self.app.logger.increment('auth_short_circuits')
                     return aresp
             if not containers:
-                self.app.logger.timing_since('POST.timing', start_time)
                 return HTTPNotFound(request=req)
             if 'x-delete-at' in req.headers:
                 try:
                     x_delete_at = int(req.headers['x-delete-at'])
                     if x_delete_at < time.time():
-                        self.app.logger.increment('errors')
                         return HTTPBadRequest(body='X-Delete-At in past',
                             request=req, content_type='text/plain')
                 except ValueError:
-                    self.app.logger.increment('errors')
                     return HTTPBadRequest(request=req,
                                           content_type='text/plain',
                                           body='Non-integer X-Delete-At')
@@ -476,7 +458,6 @@ class ObjectController(Controller):
                 headers.append(nheaders)
             resp = self.make_requests(req, self.app.object_ring, partition,
                                       'POST', req.path_info, headers)
-            self.app.logger.timing_since('POST.timing', start_time)
             return resp
 
     def _send_file(self, conn, path):
@@ -515,10 +496,8 @@ class ObjectController(Controller):
 
     @public
     @delay_denial
-    def PUT(self, req, start_time=None, stats_type='PUT'):
+    def PUT(self, req):
         """HTTP PUT request handler."""
-        if not start_time:
-            start_time = time.time()
         (container_partition, containers, _junk, req.acl,
          req.environ['swift_sync_key'], object_versions) = \
             self.container_info(self.account_name, self.container_name,
@@ -526,17 +505,13 @@ class ObjectController(Controller):
         if 'swift.authorize' in req.environ:
             aresp = req.environ['swift.authorize'](req)
             if aresp:
-                self.app.logger.increment('auth_short_circuits')
                 return aresp
         if not containers:
-            self.app.logger.timing_since(
-                '%s.timing' % (stats_type,), start_time)
             return HTTPNotFound(request=req)
         if 'x-delete-after' in req.headers:
             try:
                 x_delete_after = int(req.headers['x-delete-after'])
             except ValueError:
-                    self.app.logger.increment('errors')
                     return HTTPBadRequest(request=req,
                                           content_type='text/plain',
                                           body='Non-integer X-Delete-After')
@@ -545,11 +520,9 @@ class ObjectController(Controller):
             try:
                 x_delete_at = int(req.headers['x-delete-at'])
                 if x_delete_at < time.time():
-                    self.app.logger.increment('errors')
                     return HTTPBadRequest(body='X-Delete-At in past',
                         request=req, content_type='text/plain')
             except ValueError:
-                self.app.logger.increment('errors')
                 return HTTPBadRequest(request=req, content_type='text/plain',
                                       body='Non-integer X-Delete-At')
             delete_at_container = str(x_delete_at /
@@ -577,11 +550,8 @@ class ObjectController(Controller):
                 if hresp.environ and 'swift_x_timestamp' in hresp.environ and \
                     float(hresp.environ['swift_x_timestamp']) >= \
                         float(req.headers['x-timestamp']):
-                    self.app.logger.timing_since(
-                        '%.timing' % (stats_type,), start_time)
                     return HTTPAccepted(request=req)
             except ValueError:
-                self.app.logger.increment('errors')
                 return HTTPBadRequest(request=req, content_type='text/plain',
                     body='X-Timestamp should be a UNIX timestamp float value; '
                          'was %r' % req.headers['x-timestamp'])
@@ -596,7 +566,6 @@ class ObjectController(Controller):
             content_type_manually_set = False
         error_response = check_object_creation(req, self.object_name)
         if error_response:
-            self.app.logger.increment('errors')
             return error_response
         if object_versions and not req.environ.get('swift_versioned_copy'):
             is_manifest = 'x-object-manifest' in req.headers or \
@@ -647,7 +616,6 @@ class ObjectController(Controller):
                 src_container_name, src_obj_name = \
                     source_header.split('/', 3)[2:]
             except ValueError:
-                self.app.logger.increment('errors')
                 return HTTPPreconditionFailed(request=req,
                     body='X-Copy-From header must be of the form'
                     '<container name>/<object name>')
@@ -660,8 +628,6 @@ class ObjectController(Controller):
             self.container_name = src_container_name
             source_resp = self.GET(source_req)
             if source_resp.status_int >= HTTP_MULTIPLE_CHOICES:
-                self.app.logger.timing_since(
-                    '%s.timing' % (stats_type,), start_time)
                 return source_resp
             self.object_name = orig_obj_name
             self.container_name = orig_container_name
@@ -674,7 +640,6 @@ class ObjectController(Controller):
                 # which currently only happens because there are more than
                 # CONTAINER_LISTING_LIMIT segments in a segmented object. In
                 # this case, we're going to refuse to do the server-side copy.
-                self.app.logger.increment('errors')
                 return HTTPRequestEntityTooLarge(request=req)
             new_req.etag = source_resp.etag
             # we no longer need the X-Copy-From header
@@ -713,7 +678,6 @@ class ObjectController(Controller):
                 _('Object PUT returning 503, %(conns)s/%(nodes)s '
                 'required connections'),
                 {'conns': len(conns), 'nodes': len(nodes) // 2 + 1})
-            self.app.logger.increment('errors')
             return HTTPServiceUnavailable(request=req)
         chunked = req.headers.get('transfer-encoding')
         bytes_transferred = 0
@@ -733,7 +697,6 @@ class ObjectController(Controller):
                             break
                     bytes_transferred += len(chunk)
                     if bytes_transferred > MAX_FILE_SIZE:
-                        self.app.logger.increment('errors')
                         return HTTPRequestEntityTooLarge(request=req)
                     for conn in list(conns):
                         if not conn.failed:
@@ -745,7 +708,6 @@ class ObjectController(Controller):
                         self.app.logger.error(_('Object PUT exceptions during'
                             ' send, %(conns)s/%(nodes)s required connections'),
                             {'conns': len(conns), 'nodes': len(nodes) / 2 + 1})
-                        self.app.logger.increment('errors')
                         return HTTPServiceUnavailable(request=req)
                 for conn in conns:
                     if conn.queue.unfinished_tasks:
@@ -759,17 +721,12 @@ class ObjectController(Controller):
         except (Exception, Timeout):
             self.app.logger.exception(
                 _('ERROR Exception causing client disconnect'))
-            self.app.logger.increment('client_disconnects')
-            self.app.logger.timing_since(
-                '%s.timing' % (stats_type,), start_time)
             return HTTPClientDisconnect(request=req)
         if req.content_length and bytes_transferred < req.content_length:
             req.client_disconnect = True
             self.app.logger.warn(
                 _('Client disconnected without sending enough data'))
             self.app.logger.increment('client_disconnects')
-            self.app.logger.timing_since(
-                '%s.timing' % (stats_type,), start_time)
             return HTTPClientDisconnect(request=req)
         statuses = []
         reasons = []
@@ -795,7 +752,6 @@ class ObjectController(Controller):
         if len(etags) > 1:
             self.app.logger.error(
                 _('Object servers returned %s mismatched etags'), len(etags))
-            self.app.logger.increment('errors')
             return HTTPServerError(request=req)
         etag = len(etags) and etags.pop() or None
         while len(statuses) < len(nodes):
@@ -814,14 +770,12 @@ class ObjectController(Controller):
                 if k.lower().startswith('x-object-meta-'):
                     resp.headers[k] = v
         resp.last_modified = float(req.headers['X-Timestamp'])
-        self.app.logger.timing_since('%s.timing' % (stats_type,), start_time)
         return resp
 
     @public
     @delay_denial
     def DELETE(self, req):
         """HTTP DELETE request handler."""
-        start_time = time.time()
         (container_partition, containers, _junk, req.acl,
          req.environ['swift_sync_key'], object_versions) = \
             self.container_info(self.account_name, self.container_name)
@@ -839,10 +793,8 @@ class ObjectController(Controller):
                 # no worries, last_item is None
                 pass
             except ListingIterNotAuthorized, err:
-                self.app.logger.increment('auth_short_circuits')
                 return err.aresp
             except ListingIterError:
-                self.app.logger.increment('errors')
                 return HTTPServerError(request=req)
             if last_item:
                 # there are older versions so copy the previous version to the
@@ -880,10 +832,8 @@ class ObjectController(Controller):
         if 'swift.authorize' in req.environ:
             aresp = req.environ['swift.authorize'](req)
             if aresp:
-                self.app.logger.increment('auth_short_circuits')
                 return aresp
         if not containers:
-            self.app.logger.timing_since('DELETE.timing', start_time)
             return HTTPNotFound(request=req)
         partition, nodes = self.app.object_ring.get_nodes(
             self.account_name, self.container_name, self.object_name)
@@ -893,7 +843,6 @@ class ObjectController(Controller):
                 req.headers['X-Timestamp'] = \
                     normalize_timestamp(float(req.headers['x-timestamp']))
             except ValueError:
-                self.app.logger.increment('errors')
                 return HTTPBadRequest(request=req, content_type='text/plain',
                     body='X-Timestamp should be a UNIX timestamp float value; '
                          'was %r' % req.headers['x-timestamp'])
@@ -909,17 +858,14 @@ class ObjectController(Controller):
             headers.append(nheaders)
         resp = self.make_requests(req, self.app.object_ring,
                 partition, 'DELETE', req.path_info, headers)
-        self.app.logger.timing_since('DELETE.timing', start_time)
         return resp
 
     @public
     @delay_denial
     def COPY(self, req):
         """HTTP COPY request handler."""
-        start_time = time.time()
         dest = req.headers.get('Destination')
         if not dest:
-            self.app.logger.increment('errors')
             return HTTPPreconditionFailed(request=req,
                                           body='Destination header required')
         dest = unquote(dest)
@@ -928,7 +874,6 @@ class ObjectController(Controller):
         try:
             _junk, dest_container, dest_object = dest.split('/', 2)
         except ValueError:
-            self.app.logger.increment('errors')
             return HTTPPreconditionFailed(request=req,
                     body='Destination header must be of the form '
                          '<container name>/<object name>')
@@ -942,4 +887,4 @@ class ObjectController(Controller):
         req.headers['Content-Length'] = 0
         req.headers['X-Copy-From'] = quote(source)
         del req.headers['Destination']
-        return self.PUT(req, start_time=start_time, stats_type='COPY')
+        return self.PUT(req)
