@@ -541,30 +541,6 @@ class TestObject(unittest.TestCase):
         resp.read()
         self.assertEquals(resp.status, 204)
 
-    def test_name_control_chars(self):
-        if skip:
-            raise SkipTest
-
-        def put(url, token, parsed, conn):
-            conn.request('PUT', '%s/%s/obj%%00test' % (parsed.path,
-                self.container), 'test', {'X-Auth-Token': token})
-            return check_response(conn)
-
-        resp = retry(put)
-        resp.read()
-        # NULLs not allowed
-        self.assertEquals(resp.status, 412)
-
-        def put(url, token, parsed, conn):
-            conn.request('PUT', '%s/%s/obj%%01test' % (parsed.path,
-                self.container), 'test', {'X-Auth-Token': token})
-            return check_response(conn)
-
-        resp = retry(put)
-        resp.read()
-        # 0x01 allowed
-        self.assertEquals(resp.status, 201)
-
 
 if __name__ == '__main__':
     unittest.main()
