@@ -23,6 +23,7 @@ from contextlib import contextmanager
 from webob import Request, Response
 
 from swift.common.middleware import staticweb
+from test.unit import FakeLogger
 
 
 class FakeMemcache(object):
@@ -624,5 +625,33 @@ class TestStaticWeb(unittest.TestCase):
         self.assertEquals(resp.body, '1')
         self.assertEquals(self.app.calls, 1)
 
+    def test_log_headers(self):
+        # Using a listing request since we know that calls StaticWeb's logging
+        # routines
+        self.test_staticweb.access_logger = FakeLogger()
+        self.test_staticweb.log_headers = True
+        req = Request.blank('/v1/a/c3/subdir/',
+                            headers={'test-header': 'test-value'})
+        resp = req.get_response(self.test_staticweb)
+        self.assertEquals(resp.status_int, 200)
+        self.assert_('Listing of /v1/a/c3/subdir/' in resp.body)
+        infos = self.test_staticweb.access_logger.log_dict['info']
+        self.assertEquals(len(infos), 1)
+        info = infos[0][0][0]
+        self.assertTrue('Test-Header%3A%20test-value' in info, repr(info))
+
+        self.test_staticweb.access_logger = FakeLogger()
+        self.test_staticweb.log_headers = False
+        req = Request.blank('/v1/a/c3/subdir/',
+                            headers={'test-header': 'test-value'})
+        resp = req.get_response(self.test_staticweb)
+        self.assertEquals(resp.status_int, 200)
+        self.assert_('Listing of /v1/a/c3/subdir/' in resp.body)
+        infos = self.test_staticweb.access_logger.log_dict['info']
+        self.assertEquals(len(infos), 1)
+        info = infos[0][0][0]
+        self.assertTrue('Test-Header%3A%20test-value' not in info, repr(info))
+
+
 if __name__ == '__main__':
     unittest.main()
