@@ -175,6 +175,17 @@ class TestWSGI(unittest.TestCase):
             wsgi.sleep = old_sleep
             wsgi.time = old_time
 
+    def test_pre_auth_wsgi_input(self):
+        oldenv = {}
+        newenv = wsgi.make_pre_authed_env(oldenv)
+        self.assertTrue('wsgi.input' in newenv)
+        self.assertEquals(newenv['wsgi.input'].read(), '')
+
+        oldenv = {'wsgi.input': StringIO('original wsgi.input')}
+        newenv = wsgi.make_pre_authed_env(oldenv)
+        self.assertTrue('wsgi.input' in newenv)
+        self.assertEquals(newenv['wsgi.input'].read(), '')
+
     def test_pre_auth_req(self):
         class FakeReq(object):
             @classmethod
